Hello
I have a big data file (250k rows by 2k columns) which contains production data from electronic Integrated Circuit devices (ICs).
And I have a jsl script which i use to evaluate the results and look for patterns in the data, but in such a big data table it takes hours to complete a run.
To read/write a cell I was using dt:MeasureX[Row] but that instruction seems to be not execution efficient, so i switched to Column( dt, "MeasureX" )[intRow] and this one is like 20% faster to execute.
Are there tricks to improve the execution time? like stopping the table window refresh while the script is executing...
Thanks